@@ -3,10 +3,7 @@ from typing import Optional, Union
 
 import abjad
 
-from ..utilities.remove_repeated_dynamics import remove_repeated_dynamics
-from ..utilities.remove_repeated_time_signatures import (
-    remove_repeated_time_signatures,
-)
+from ..utilities.mutate import mutate
 from .TenneySelector import TenneySelector
 
 
@@ -37,7 +34,7 @@ class PitchRandomiser:
             fs'4
         }
 
-        .. figure:: ../_images/image-PitchRandomiser-1.png
+        .. figure:: ../_images/PitchRandomiser-134lqskbb6o.png
 
         >>> notes = randomiser()
         >>> staff = abjad.Staff(notes)
@@ -51,7 +48,7 @@ class PitchRandomiser:
             fs'4
         }
 
-        .. figure:: ../_images/image-PitchRandomiser-2.png
+        .. figure:: ../_images/PitchRandomiser-z66g1fy8nm8.png
 
         To get the result of the last operation, use the property
         :attr:`current_window`.
@@ -68,9 +65,9 @@ class PitchRandomiser:
             fs'4
         }
 
-        .. figure:: ../_images/image-PitchRandomiser-3.png
+        .. figure:: ../_images/PitchRandomiser-x0e6yduogh.png
 
-    ..  warning::
+    .. warning::
 
         Unlike the other classes in Auxjad, the very first call of this class
         will already process the initial container. To disable this behaviour
@@ -95,7 +92,7 @@ class PitchRandomiser:
             f'4
         }
 
-        .. figure:: ../_images/image-PitchRandomiser-4.png
+        .. figure:: ../_images/PitchRandomiser-640x6vsjwtk.png
 
         >>> notes = randomiser()
         >>> staff = abjad.Staff(notes)
@@ -108,7 +105,7 @@ class PitchRandomiser:
             fs'4
         }
 
-        .. figure:: ../_images/image-PitchRandomiser-5.png
+        .. figure:: ../_images/PitchRandomiser-vsjdj8gkanj.png
 
     :func:`len()`:
         Applying the :func:`len()` function to the randomiser will return the
@@ -170,9 +167,9 @@ class PitchRandomiser:
         >>> randomiser.omit_time_signatures = False
         >>> randomiser.process_on_first_call = False
         >>> randomiser.use_tenney_selector = False
-        >>> assert randomiser.pitches
+        >>> randomiser.pitches
         <c' d' e' f'>
-        >>> assert randomiser.weights
+        >>> randomiser.weights
         [1, 2, 5, 8]
         >>> randomiser.omit_time_signatures
         False
@@ -202,13 +199,14 @@ class PitchRandomiser:
             a'8.
         }
 
-        .. figure:: ../_images/image-PitchRandomiser-6.png
+        .. figure:: ../_images/PitchRandomiser-u4294ozm92.png
 
     Chords:
         Each note of a chord is randomised too.
 
         >>> container = abjad.Container(
-        ...     r"<c' e' g'>8. d'4 r8 r8. e'16 <f' a'>8.")
+        ...     r"<c' e' g'>8. d'4 r8 r8. e'16 <f' a'>8."
+        ... )
         >>> pitches = [6, 7, 8, 9, 10, 11]
         >>> randomiser = auxjad.PitchRandomiser(container,
         ...                                     pitches,
@@ -226,13 +224,14 @@ class PitchRandomiser:
             <fs' bf'>8.
         }
 
-        .. figure:: ../_images/image-PitchRandomiser-7.png
+        .. figure:: ../_images/PitchRandomiser-318eldj7tzc.png
 
-        The number of note heads in a chord stay the same unless there are
-        fewer pitches available in :attr:`pitches`.
+        The number of notes in a chord stay the same unless there are fewer
+        pitches available in :attr:`pitches`.
 
         >>> container = abjad.Container(
-        ...     r"<c' e' g' a'>2 <cs' ds' e' f' g' a' b'>2")
+        ...     r"<c' e' g' a'>2 <cs' ds' e' f' g' a' b'>2"
+        ... )
         >>> pitches = [6, 7, 8]
         >>> randomiser = auxjad.PitchRandomiser(container,
         ...                                     pitches,
@@ -246,7 +245,7 @@ class PitchRandomiser:
             <fs' g' af'>2
         }
 
-        .. figure:: ../_images/image-PitchRandomiser-8.png
+        .. figure:: ../_images/PitchRandomiser-cciyee49qrj.png
 
     :attr:`use_tenney_selector`:
         Setting :attr:`use_tenney_selector` to ``True`` will make the
@@ -277,7 +276,7 @@ class PitchRandomiser:
             fs'8
         }
 
-        .. figure:: ../_images/image-PitchRandomiser-9.png
+        .. figure:: ../_images/PitchRandomiser-tmxllu13pa8.png
 
     :attr:`weights`:
         Individual pitches can have different weights, defined by the
@@ -305,7 +304,7 @@ class PitchRandomiser:
             a'8
         }
 
-        .. figure:: ../_images/image-PitchRandomiser-10.png
+        .. figure:: ../_images/PitchRandomiser-zkvbzd1brgq.png
 
     :attr:`weights` and :attr:`use_tenney_selector`:
         Non-uniform :attr:`weights` can also be used when
@@ -333,7 +332,7 @@ class PitchRandomiser:
             b'8
         }
 
-        .. figure:: ../_images/image-PitchRandomiser-11.png
+        .. figure:: ../_images/PitchRandomiser-cq1nobkjozg.png
 
     Resetting :attr:`weights`:
         Setting :attr:`weights` to ``None`` will reset it back to a uniform
@@ -360,7 +359,7 @@ class PitchRandomiser:
             fs'8
         }
 
-        .. figure:: ../_images/image-PitchRandomiser-12.png
+        .. figure:: ../_images/PitchRandomiser-wtl5o15q5qp.png
 
         >>> randomiser.weights = None
         >>> notes = randomiser()
@@ -378,7 +377,7 @@ class PitchRandomiser:
             b'8
         }
 
-        .. figure:: ../_images/image-PitchRandomiser-13.png
+        .. figure:: ../_images/PitchRandomiser-4bqe6cbawg6.png
 
     Changing :attr:`pitches`:
         When using a custom :obj:`list` of :attr:`weights`, changing the
@@ -404,7 +403,7 @@ class PitchRandomiser:
         >>> randomiser.weights
         None
 
-    ..  error::
+    .. error::
 
         Note that :attr:`weights` must always have the same length as
         :attr:`pitches`, otherwise a :exc:`ValueError` exception will be
@@ -453,13 +452,14 @@ class PitchRandomiser:
             r16
         }
 
-        .. figure:: ../_images/image-PitchRandomiser-14.png
+        .. figure:: ../_images/PitchRandomiser-fvwaaz3vgi.png
 
     Indicators:
         This class preserves indicators.
 
         >>> container = abjad.Container(
-        ...     r"c'4\p\< ~ c'8. d'16-.\f e'4--\pp f'8.( g'16)")
+        ...     r"c'4\p\< ~ c'8. d'16-.\f e'4--\pp f'8.( g'16)"
+        ... )
         >>> pitches = [6, 7, 8, 9, 10, 11, 12]
         >>> randomiser = auxjad.PitchRandomiser(container,
         ...                                     pitches,
@@ -486,13 +486,14 @@ class PitchRandomiser:
             )
         }
 
-        .. figure:: ../_images/image-PitchRandomiser-15.png
+        .. figure:: ../_images/PitchRandomiser-2e647eng8yc.png
 
     Example:
         This class also preserves the time signature structure.
 
         >>> container = abjad.Container(
-        ...     r"\time 3/4 c'4 d'2 \time 2/4 e'8 f'8 g'8 a'8")
+        ...     r"\time 3/4 c'4 d'2 \time 2/4 e'8 f'8 g'8 a'8"
+        ... )
         >>> pitches = r"fs' gs' a' b'"
         >>> randomiser = auxjad.PitchRandomiser(container,
         ...                                     pitches,
@@ -512,14 +513,15 @@ class PitchRandomiser:
             gs'8
         }
 
-        .. figure:: ../_images/image-PitchRandomiser-16.png
+        .. figure:: ../_images/PitchRandomiser-c9t7r3thrqg.png
 
     :attr:`omit_time_signatures`:
         To omit time signatures altogether, set :attr:`omit_time_signatures` to
         ``True`` (default is ``False``).
 
         >>> container = abjad.Container(
-        ...     r"\time 3/4 c'4 d'2 \time 2/4 e'8 f'8 g'8 a'8")
+        ...     r"\time 3/4 c'4 d'2 \time 2/4 e'8 f'8 g'8 a'8"
+        ... )
         >>> pitches = r"fs' gs' a' b'"
         >>> randomiser = auxjad.PitchRandomiser(container,
         ...                                     pitches,
@@ -538,14 +540,14 @@ class PitchRandomiser:
             gs'8
         }
 
-        .. figure:: ../_images/image-PitchRandomiser-17.png
+        .. figure:: ../_images/PitchRandomiser-mwruvbmgu3o.png
 
     Using as iterator:
         The instances of this class can also be used as an iterator, which can
         then be used in a for loop. Note that unlike the method
         :meth:`output_n`, time signatures are added to each window returned by
         the randomiser. Use the function
-        :func:`auxjad.remove_repeated_time_signatures()` to clean the output
+        |auxjad.mutate().remove_repeated_time_signatures()| to clean the output
         when using this class in this way. It is also important to note that a
         ``break`` statement is needed when using this class as an iterator. The
         reason is that pitch randomisation is a process that can happen
@@ -561,7 +563,7 @@ class PitchRandomiser:
         ...     staff.append(window)
         ...     if abjad.inspect(staff).duration() == abjad.Duration((9, 4)):
         ...         break
-        >>> auxjad.remove_repeated_time_signatures(staff)
+        >>> auxjad.mutate(staff).remove_repeated_time_signatures()
         >>> abjad.f(staff)
         \new Staff
         {
@@ -577,13 +579,13 @@ class PitchRandomiser:
             cs''4
         }
 
-        .. figure:: ../_images/image-PitchRandomiser-18.png
+        .. figure:: ../_images/PitchRandomiser-2c9zzip8tpc.png
 
     .. tip::
 
-        The functions :func:`auxjad.remove_repeated_dynamics()` and
-        :func:`auxjad.reposition_clefs()` can be used to clean the output and
-        remove repeated dynamics and unnecessary clef changes.
+        The functions |auxjad.mutate().remove_repeated_dynamics()| and
+        |auxjad.mutate().reposition_clefs()| can be used to clean the output
+        and remove repeated dynamics and unnecessary clef changes.
     """
 
     ### CLASS VARIABLES ###
@@ -660,8 +662,8 @@ class PitchRandomiser:
         dummy_container = abjad.Container()
         for _ in range(n):
             dummy_container.append(self.__call__())
-        remove_repeated_time_signatures(dummy_container)
-        remove_repeated_dynamics(dummy_container)
+        mutate(dummy_container[:]).remove_repeated_time_signatures()
+        mutate(dummy_container[:]).remove_repeated_dynamics()
         output = dummy_container[:]
         dummy_container[:] = []
         return output
